===================================
``psyclone.domain.lfric.algorithm``
===================================

.. automodule:: psyclone.domain.lfric.algorithm

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.domain.lfric.algorithm.psyir

.. currentmodule:: psyclone.domain.lfric.algorithm


Classes
=======

- :py:class:`LFRicAlgorithmInvokeCall`:
  An invoke call from the LFRic Algorithm layer.

- :py:class:`LFRicKernelFunctor`:
  Object containing an LFRic kernel call, a description of its

- :py:class:`LFRicBuiltinFunctor`:
  Object containing an LFRic builtin call, a description of its


.. autoclass:: LFRicAlgorithmInvokeCall
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LFRicAlgorithmInvokeCall
      :parts: 1

.. autoclass:: LFRicKernelFunctor
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LFRicKernelFunctor
      :parts: 1

.. autoclass:: LFRicBuiltinFunctor
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LFRicBuiltinFunctor
      :parts: 1
